@@ -17,4 +17,4 @@ xpt, ypt = m(lon_0, lat_0)
 m.plot([xpt],[ypt],'ko') 
 # draw the title.
 plt.title('Azimuthal Equidistant Projection')
-plt.savefig('aeqd.png')
+plt.show()
