@@ -11,4 +11,4 @@ m.drawparallels(np.arange(-90.,120.,30.))
 m.drawmeridians(np.arange(0.,420.,60.))
 m.drawmapboundary(fill_color='aqua') 
 plt.title("Hammer Projection")
-plt.savefig('hammer.png')
+plt.show()
