@@ -14,4 +14,4 @@ m.drawparallels(np.arange(-90.,91.,30.))
 m.drawmeridians(np.arange(-180.,181.,60.))
 m.drawmapboundary(fill_color='aqua') 
 plt.title("Miller Cylindrical Projection")
-plt.savefig('mill.png')
+plt.show()
