@@ -71,6 +71,22 @@ plt.title('Gall Stereographic Cylindrical',y=1.1)
 print('plotting Gall Stereographic Cylindrical example ...')
 print(m.proj4string)
 
+# create new figure
+fig=plt.figure()
+# setup cylindrical equal area map projection.
+m = Basemap(llcrnrlon=-180.,llcrnrlat=-90,urcrnrlon=180.,urcrnrlat=90.,\
+            resolution='c',area_thresh=10000.,lat_ts=30,projection='cea')
+# plot image over map.
+im = m.pcolormesh(lons,lats,topodat,cmap=cmap,latlon=True)
+cb = m.colorbar() # draw colorbar
+m.drawcoastlines() # draw coastlines
+# draw parallels and meridiands
+m.drawparallels(np.arange(-90,90,30),labels=[1,0,0,1])
+m.drawmeridians(np.arange(0,360,60),labels=[1,0,0,1])
+plt.title('Cylindrical Equal Area',y=1.1)
+print('plotting Cylindrical Equal Area example ...')
+print(m.proj4string)
+
 # create new figure
 fig=plt.figure()
 # setup mercator map projection (-80 to +80).
@@ -335,9 +351,9 @@ print(m.proj4string)
 # create new figure
 fig=plt.figure()
 # setup lambert azimuthal map projection (Northern Hemisphere).
-#m = Basemap(llcrnrlon=-150.,llcrnrlat=-18.,urcrnrlon=30.,urcrnrlat=--18.,\
-#            resolution='c',area_thresh=10000.,projection='laea',\
-#            lat_0=90.,lon_0=-105.)
+m = Basemap(llcrnrlon=-150.,llcrnrlat=-18.,urcrnrlon=30.,urcrnrlat=--18.,\
+            resolution='c',area_thresh=10000.,projection='laea',\
+            lat_0=90.,lon_0=-105.)
 # plot image over map.
 cs = m.contourf(lons,lats,topodat,50,cmap=cmap,extend='both',latlon=True)
 m.colorbar(pad='12%') # draw colorbar
@@ -353,6 +369,22 @@ plt.title('Square Lambert Azimuthal Equal Area',y=1.075)
 print('plotting Square Lambert Azimuthal example ...')
 print(m.proj4string)
 
+# create new figure
+fig=plt.figure()
+m = Basemap(projection = 'rotpole',lon_0 = -120.,\
+            o_lon_p = 180, o_lat_p = 0,\
+            llcrnry = -41.75, urcrnry = 37.75,\
+            llcrnrx = 137, urcrnrx = 222.5, resolution = 'l')
+m.drawcoastlines()
+ny,nx = lons.shape
+m.contourf(lons[ny/2:,:],lats[ny/2:,:],topodat[ny/2:,:],50,cmap=cmap,extend='both',latlon=True)
+m.drawmeridians(np.arange(-180,180,20),labels=[1,1,1,1])
+m.drawparallels(np.arange(20,80,20))
+m.colorbar()
+plt.title('Rotated Pole',y=1.075)
+print('plotting Rotated Pole example ...')
+print(m.proj4string)
+
 # create new figure
 fig=plt.figure()
 m = Basemap(lon_0=-105,boundinglat=20.,
@@ -411,7 +443,7 @@ cs = m.contourf(lons,lats,topodat,50,cmap=cmap,extend='both',latlon=True)
 m.colorbar() # draw colorbar
 # draw coastlines and political boundaries.
 m.drawcoastlines()
-# draw parallels and meridians (labelling is 
+# draw parallels and meridians (labelling is
 # not implemented for orthographic).
 parallels = np.arange(-80.,90,20.)
 m.drawparallels(parallels)
@@ -433,7 +465,7 @@ cs = m.contourf(lons,lats,topodat,50,cmap=cmap,extend='both',latlon=True)
 m.colorbar() # draw colorbar
 # draw coastlines and political boundaries.
 m.drawcoastlines()
-# draw parallels and meridians (labelling is 
+# draw parallels and meridians (labelling is
 # not implemented for geostationary).
 parallels = np.arange(-80.,90,20.)
 m.drawparallels(parallels)
